import React, { HTMLAttributes } from 'react';
import './CIcon.css';
export interface CIconProps extends Omit<HTMLAttributes<SVGSVGElement>, 'content'> {
    /**
     * A string of all className you want applied to the component.
     */
    className?: string;
    /**
     * Use `icon={...}` instead of
     *
     * @deprecated 3.0
     */
    content?: string | string[];
    /**
     * Use for replacing default CIcon component classes. Prop is overriding the 'size' prop.
     */
    customClassName?: string | string[];
    /**
     * Name of the icon placed in React object or SVG content.
     */
    icon?: string | string[];
    /**
     * The height attribute defines the vertical length of an icon.
     */
    height?: number;
    /**
     * Use `icon="..."` instead of
     *
     * @deprecated 3.0
     */
    name?: string;
    /**
     * Size of the icon. Available sizes: 'sm', 'lg', 'xl', 'xxl', '3xl...9xl', 'custom', 'custom-size'.
     */
    size?: 'custom' | 'custom-size' | 'sm' | 'lg' | 'xl' | 'xxl' | '3xl' | '4xl' | '5xl' | '6xl' | '7xl' | '8xl' | '9xl';
    /**
     * If defined component will be rendered using 'use' tag.
     */
    use?: string;
    /**
     * The viewBox attribute defines the position and dimension of an SVG viewport.
     */
    viewBox?: string;
    /**
     * Title tag content.
     */
    title?: string;
    /**
     * The width attribute defines the horizontal length of an icon.
     */
    width?: number;
}
export declare const CIcon: React.ForwardRefExoticComponent<CIconProps & React.RefAttributes<SVGSVGElement>>;
